@@ -840,14 +840,10 @@ def nlpm(word,model,words_list1,words_list2,modelname):
     #good_synonyms = ['great', 'excellent', 'superb']
     #bad_synonyms = ['terrible', 'awful', 'dreadful']
     #beautiful_synonyms = ['gorgeous', 'stunning', 'elegant']
-    happy_synonyms = ['glad', 'joyful', 'elated', 'pleased', 'content', 'cheerful', 'ecstatic', 'overjoyed', 'thrilled',
-                      'delighted', 'satisfied']
-    angry_synonyms = ['upset', 'mad', 'irate', 'furious', 'enraged', 'incensed', 'outraged', 'livid', 'exasperated',
-                      'aggravated', 'infuriated']
-    run_synonyms = ['jog', 'sprint', 'dash', 'gallop', 'jogging', 'trot', 'race', 'jogged', 'running', 'sprinted',
-                    'dashing']
-    big_synonyms = ['large', 'huge', 'enormous', 'gigantic', 'massive', 'colossal', 'vast', 'immense', 'monstrous',
-                    'tremendous', 'substantial']
+    happy_synonyms = ['glad', 'joyful', 'elated', 'pleased', 'content', 'cheerful', 'ecstatic', 'overjoyed', 'thrilled','delighted', 'satisfied']
+    angry_synonyms = ['upset', 'mad', 'irate', 'furious', 'enraged', 'incensed', 'outraged', 'livid', 'exasperated','aggravated', 'infuriated']
+    run_synonyms = ['jog', 'sprint', 'dash', 'gallop', 'jogging', 'trot', 'race', 'jogged', 'running', 'sprinted', 'dashing']
+    big_synonyms = ['large', 'huge', 'enormous', 'gigantic', 'massive', 'colossal', 'vast', 'immense', 'monstrous', 'tremendous', 'substantial']
     small_synonyms = ['tiny', 'minuscule', 'microscopic', 'miniature', 'little', 'diminutive', 'petite', 'pocket-sized',
                       'dinky', 'wee', 'puny']
     hot_synonyms = ['warm', 'toasty', 'boiling', 'scorching', 'sweltering', 'blistering', 'roasting', 'sizzling',
@@ -922,12 +918,22 @@ def nlpm(word,model,words_list1,words_list2,modelname):
     laugh = ['giggle', 'chuckle', 'snicker', 'cackle', 'roar', 'snort', 'chortle', 'laughing', 'guffaw','hearty', 'hilarious']
     cry = ['weep', 'sob', 'whimper', 'sniffle', 'blubber', 'tear', 'wail', 'bawl', 'lament', 'mourn', 'sorrow']
     synonyms = {
+        'communication':network,
+        'blissful':happy2,
+        'unhappy':sad,
+        'disheartened':sad,
+        'repulsive':ugly,
+        'electronics':hardware,
+        'devices':hardware,
+        'sob':cry,
+        'tear':cry,
         'giggle':laugh,
         'ugly':ugly,
         'sad':sad,
         'laugh':laugh,
         'cry':cry,
         'ai':AI,
+        'artificial intelligence': AI,
         'data':data,
         'network':network,
         'software':software,
@@ -1014,7 +1020,7 @@ def nlpm(word,model,words_list1,words_list2,modelname):
         'hope':hope
     }
     def run(modelname,word,model):
-        x = model_load(modelname,word,model)
+        x = model_load(modelname,word,model,modelname)
         output = rephrase_sentence(x, synonyms)
         return output
     return run(modelname,word,model)
